@@ -1,7 +1,7 @@
 package App::LintPrereqs;
 
-our $DATE = '2015-10-18'; # DATE
-our $VERSION = '0.32'; # VERSION
+our $DATE = '2016-01-29'; # DATE
+our $VERSION = '0.33'; # VERSION
 
 use 5.010001;
 use strict;
@@ -99,8 +99,9 @@ $SPEC{lint_prereqs} = {
 Check `[Prereqs / *]` (as well as `OSPrereqs`, `Extras/lint-prereqs/Assume-*`)
 sections in your `dist.ini` against what's actually being used in your Perl code
 (using `Perl::PrereqScanner::Lite`) and what's in Perl core list of modules.
-Will complain if your prerequisites are not actually used, or already in Perl
-core. Will also complain if there are missing prerequisites.
+Will complain if your prerequisites are not actually used (extraneous
+dependencies), or if there are missing prerequisites. Will also complain if a
+prerequisite is already in Perl core (but this can be configured).
 
 Designed to work with prerequisites that are manually written. Does not work if
 you use AutoPrereqs.
@@ -146,9 +147,18 @@ Lite is faster but it might still miss detecting some modules.
 
 _
         },
-    },
-    deps => {
-        prog => 'scan_prereqs',
+        core_prereqs => {
+            schema => ['bool*'],
+            default => 0,
+            summary => 'Whether or not prereqs to core modules are allowed',
+            description => <<'_',
+
+If set to 0 (the default), will complain if there are prerequisites to core
+modules. If set to 1, prerequisites to core modules are required just like other
+modules.
+
+_
+        },
     },
 };
 sub lint_prereqs {
@@ -258,12 +268,14 @@ sub lint_prereqs {
         my $v = $mods_from_ini{$mod};
         next if $mod eq 'perl';
         $log->tracef("Checking mod from dist.ini: %s (%s)", $mod, $v);
-        if (Module::CoreList::More->is_still_core($mod, $v, $perlv)
-              && !exists($allow_core{$mod})) {
+        my $is_core = Module::CoreList::More->is_still_core($mod, $v, $perlv);
+        if (!$args{core_prereqs} && $is_core && !exists($allow_core{$mod})) {
             push @errs, {
                 module  => $mod,
+                req_v   => $v,
+                is_core => 1,
                 error   => "Core in perl ($perlv to latest) but ".
-                    "mentioned in dist.ini ($v)",
+                    "mentioned in dist.ini",
                 remedy  => "Remove from dist.ini",
             };
         }
@@ -271,6 +283,8 @@ sub lint_prereqs {
         if (defined($scanv) && $scanv != 0 && version_ne($v, $scanv)) {
             push @errs, {
                 module  => $mod,
+                req_v   => $v,
+                is_core => $is_core,
                 error   => "Version mismatch between dist.ini ($v) ".
                     "and from scanned_prereqs ($scanv)",
                 remedy  => "Fix either the code or version in dist.ini",
@@ -279,6 +293,8 @@ sub lint_prereqs {
         unless (defined($scanv) || exists($assume_used{$mod})) {
             push @errs, {
                 module  => $mod,
+                req_v   => $v,
+                is_core => $is_core,
                 error   => "Unused but listed in dist.ini",
                 remedy  => "Remove from dist.ini",
             };
@@ -300,11 +316,15 @@ sub lint_prereqs {
         last unless %lumped_mods;
         $log->tracef("Checking lumped modules");
         for my $mod (keys %lumped_mods) {
+            my $v = $mods_from_ini{$mod};
+            my $is_core = Module::CoreList::More->is_still_core($mod, $v, $perlv);
             if (exists $mods_from_ini{$mod}) {
                 push @errs, {
-                    module => $mod,
-                    error  => "Listed in dist.ini but already lumped in $lumped_mods{$mod}",
-                    remedy => "Remove one of $mod or $lumped_mods{$mod} from dist.ini",
+                    module  => $mod,
+                    req_v   => $v,
+                    is_core => $is_core,
+                    error   => "Listed in dist.ini but already lumped in $lumped_mods{$mod}",
+                    remedy  => "Remove one of $mod or $lumped_mods{$mod} from dist.ini",
                 };
             }
         }
@@ -318,9 +338,11 @@ sub lint_prereqs {
         next if exists $pkgs{$mod};
         unless (exists($mods_from_ini{$mod}) ||
                     exists($assume_provided{$mod}) ||
-                    $is_core) {
+                        ($args{core_prereqs} ? 0 : $is_core)) {
             push @errs, {
                 module  => $mod,
+                req_v   => $v,
+                is_core => $is_core,
                 error   => "Used but not listed in dist.ini",
                 remedy  => "Put '$mod=$v' in dist.ini",
             };
@@ -329,7 +351,7 @@ sub lint_prereqs {
 
     my $resmeta = {
         "cmdline.exit_code" => @errs ? 500-300:0,
-        "format_options" => {any=>{table_column_orders=>[[qw/module error remedy/]]}},
+        "table.fields" => [qw/module req_v is_core error remedy/],
     };
     [200, @errs ? "Extraneous/missing dependencies" : "OK", \@errs, $resmeta];
 }
@@ -349,7 +371,7 @@ App::LintPrereqs - Check extraneous/missing prerequisites in dist.ini
 
 =head1 VERSION
 
-This document describes version 0.32 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2015-10-18.
+This document describes version 0.33 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2016-01-29.
 
 =head1 SYNOPSIS
 
@@ -365,8 +387,9 @@ Check extraneous/missing prerequisites in dist.ini.
 Check C<[Prereqs / *]> (as well as C<OSPrereqs>, C<Extras/lint-prereqs/Assume-*>)
 sections in your C<dist.ini> against what's actually being used in your Perl code
 (using C<Perl::PrereqScanner::Lite>) and what's in Perl core list of modules.
-Will complain if your prerequisites are not actually used, or already in Perl
-core. Will also complain if there are missing prerequisites.
+Will complain if your prerequisites are not actually used (extraneous
+dependencies), or if there are missing prerequisites. Will also complain if a
+prerequisite is already in Perl core (but this can be configured).
 
 Designed to work with prerequisites that are manually written. Does not work if
 you use AutoPrereqs.
@@ -400,6 +423,14 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<core_prereqs> => I<bool> (default: 0)
+
+Whether or not prereqs to core modules are allowed.
+
+If set to 0 (the default), will complain if there are prerequisites to core
+modules. If set to 1, prerequisites to core modules are required just like other
+modules.
+
 =item * B<lite> => I<bool> (default: 1)
 
 Use Perl::PrereqScanner::Lite instead of Perl::PrereqScanner.
@@ -429,7 +460,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-LintPr
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-App-LintPrereqs>.
+Source repository is at L<https://github.com/sharyanto/perl-App-LintPrereqs>.
 
 =head1 BUGS
 
@@ -445,7 +476,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
